pub struct UnlockConfig;Trait Implementations
Sourceimpl UnlockConfig<()> for UnlockConfig
impl UnlockConfig<()> for UnlockConfig
Sourcetype DataDepositPerByte = DataDepositPerByte
type DataDepositPerByte = DataDepositPerByte
Deposit per byte to report a tip. Read more
Sourcetype TipReportDepositBase = TipReportDepositBase
type TipReportDepositBase = TipReportDepositBase
Base deposit to report a tip. Read more
Sourcetype AccountId = <<MultiSignature as Verify>::Signer as IdentifyAccount>::AccountId
type AccountId = <<MultiSignature as Verify>::Signer as IdentifyAccount>::AccountId
The account ID used in the runtime.
Sourcetype BlockNumber = <<<Runtime as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
type BlockNumber = <<<Runtime as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
The block number as configured in the runtime.
Sourcetype DbWeight = <Runtime as Config>::DbWeight
type DbWeight = <Runtime as Config>::DbWeight
The DB weight as configured in the runtime to calculate the correct weight.
Sourcetype PalletName = TipsPalletName
type PalletName = TipsPalletName
The name of the pallet as previously configured in
construct_runtime!.Sourceimpl UnlockConfig for UnlockConfig
impl UnlockConfig for UnlockConfig
Sourcetype MaxVotes = ConstU32<100>
type MaxVotes = ConstU32<100>
The maximum number of votes as configured previously in the runtime.
Sourcetype MaxDeposits = ConstU32<100>
type MaxDeposits = ConstU32<100>
The maximum deposit as configured previously in the runtime.
Sourcetype AccountId = <<MultiSignature as Verify>::Signer as IdentifyAccount>::AccountId
type AccountId = <<MultiSignature as Verify>::Signer as IdentifyAccount>::AccountId
The account ID used in the runtime.
Sourcetype BlockNumber = <<<Runtime as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
type BlockNumber = <<<Runtime as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
The block number as configured in the runtime.
Sourcetype DbWeight = <Runtime as Config>::DbWeight
type DbWeight = <Runtime as Config>::DbWeight
The DB weight as configured in the runtime to calculate the correct weight.
Sourcetype PalletName = DemocracyPalletName
type PalletName = DemocracyPalletName
The name of the pallet as previously configured in
construct_runtime!.Sourceimpl UnlockConfig for UnlockConfig
impl UnlockConfig for UnlockConfig
Sourcetype MaxVotesPerVoter = ConstU32<16>
type MaxVotesPerVoter = ConstU32<16>
The maximum number of votes per voter as configured previously in the previous runtime.
Sourcetype PalletId = PhragmenElectionPalletId
type PalletId = PhragmenElectionPalletId
Identifier for the elections-phragmen pallet’s lock, as previously configured in the
runtime.
Sourcetype AccountId = <<MultiSignature as Verify>::Signer as IdentifyAccount>::AccountId
type AccountId = <<MultiSignature as Verify>::Signer as IdentifyAccount>::AccountId
The account ID used in the runtime.
Sourcetype DbWeight = <Runtime as Config>::DbWeight
type DbWeight = <Runtime as Config>::DbWeight
The DB weight as configured in the runtime to calculate the correct weight.
Sourcetype PalletName = PhragmenElectionPalletName
type PalletName = PhragmenElectionPalletName
The name of the pallet as previously configured in
construct_runtime!.Auto Trait Implementations
impl Freeze for UnlockConfig
impl RefUnwindSafe for UnlockConfig
impl Send for UnlockConfig
impl Sync for UnlockConfig
impl Unpin for UnlockConfig
impl UnsafeUnpin for UnlockConfig
impl UnwindSafe for UnlockConfig