pub struct SessionKeys {
pub grandpa: <Grandpa as BoundToRuntimeAppPublic>::Public,
pub babe: <Babe as BoundToRuntimeAppPublic>::Public,
pub para_validator: <Initializer as BoundToRuntimeAppPublic>::Public,
pub para_assignment: <ParaSessionInfo as BoundToRuntimeAppPublic>::Public,
pub authority_discovery: <AuthorityDiscovery as BoundToRuntimeAppPublic>::Public,
pub beefy: <Beefy as BoundToRuntimeAppPublic>::Public,
}Expand description
Generated by impl_opaque_keys!.
Fields
grandpa: <Grandpa as BoundToRuntimeAppPublic>::Publicbabe: <Babe as BoundToRuntimeAppPublic>::Publicpara_validator: <Initializer as BoundToRuntimeAppPublic>::Publicpara_assignment: <ParaSessionInfo as BoundToRuntimeAppPublic>::Publicbeefy: <Beefy as BoundToRuntimeAppPublic>::PublicImplementations
Sourceimpl SessionKeys
impl SessionKeys
Sourcepub fn generate(
owner: &[u8],
seed: Option<Vec<u8>>,
) -> GeneratedSessionKeys<Self, (<<Grandpa as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Babe as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Initializer as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<ParaSessionInfo as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<AuthorityDiscovery as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Beefy as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession)>
pub fn generate( owner: &[u8], seed: Option<Vec<u8>>, ) -> GeneratedSessionKeys<Self, (<<Grandpa as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Babe as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Initializer as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<ParaSessionInfo as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<AuthorityDiscovery as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Beefy as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession)>
Generate a set of keys with optionally using the given seed.
The generated key pairs are stored in the keystore.
-
owner: Some bytes that will be signed by the generated private keys. These signatures are put into a tuple in the same order as the public keys. The SCALE encoded signature tuple corresponds to theproofreturned by this function. -
seed: Optionalseedfor seeding the private key generation.
Returns the generated public session keys and proof.
Sourcepub fn into_raw_public_keys(self) -> Vec<(Vec<u8>, KeyTypeId)>
pub fn into_raw_public_keys(self) -> Vec<(Vec<u8>, KeyTypeId)>
Converts Self into a Vec of (raw public key, KeyTypeId).
Sourcepub fn decode_into_raw_public_keys(
encoded: &[u8],
) -> Option<Vec<(Vec<u8>, KeyTypeId)>>
pub fn decode_into_raw_public_keys( encoded: &[u8], ) -> Option<Vec<(Vec<u8>, KeyTypeId)>>
Decode Self from the given encoded slice and convert Self into the raw public
keys (see Self::into_raw_public_keys).
Returns None when the decoding failed, otherwise Some(_).
Sourcepub fn create_ownership_proof(
&mut self,
owner: &[u8],
) -> Result<(<<Grandpa as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Babe as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Initializer as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<ParaSessionInfo as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<AuthorityDiscovery as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Beefy as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession), ()>
pub fn create_ownership_proof( &mut self, owner: &[u8], ) -> Result<(<<Grandpa as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Babe as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Initializer as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<ParaSessionInfo as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<AuthorityDiscovery as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession, <<Beefy as BoundToRuntimeAppPublic>::Public as RuntimeAppPublic>::ProofOfPossession), ()>
Create the ownership proof.
owner: Some bytes that will be signed by the private keys associated to the public keys in this session key object. These signatures are put into a tuple in the same order as the public keys. The SCALE encoded signature tuple corresponds to theproofreturned by this function.
Returns the SCALE encoded proof that will proof the ownership of the keys for user.
An error is returned if the signing of user failed, e.g. a private key isn’t present in the keystore.