Module rococo_runtime::xcm_config
source · Expand description
XCM configuration for Rococo.
Structs
- The base fee for the message delivery fees.
- The amount of weight an XCM operation takes. This is a safe overestimate.
- The asset ID for the asset that we use to pay for message delivery fees.
Type Aliases
- The barriers one of which must be passed for an XCM message to be executed.
- Type to convert the Fellows origin to a Plurality
MultiLocationvalue. - Our asset transactor. This is what allows us to interest with the runtime facilities from the point of view of XCM-only concepts like
MultiLocationandMultiAsset. - Type to convert an
Origintype value into aMultiLocationvalue which represents an interior location of this chain. - Type to convert a pallet
Origintype value into aMultiLocationvalue which represents an interior location of this chain for a destination chain. - Type to convert the
StakingAdminorigin to a PluralityMultiLocationvalue. - The XCM router. When we want to send an XCM message, we use this type. It amalgamates all of our individual routers.